# Install.ps1

function GetEnvVar($name, $legacyName)
{
    $value = [environment]::GetEnvironmentVariable($name)

    if (($null -eq $value) -and ($null -ne $legacyName))
    {
        $value = [environment]::GetEnvironmentVariable($legacyName)
    }

    return $value
}

function Log($message)
{
    Write-Output "[$(Get-Date)] $message"
}

Log "Starting installation: Contrast Site Extension - .NET Framework"

# If using yaml config check for yaml file existence
$configPath = GetEnvVar "CONTRAST_CONFIG_PATH" $null
if ($configPath)
{
    if (!(Test-Path $configPath))
    {
        Log "The provided yaml config path '$configPath' does not exist.  Please make sure to upload it."
    }
}
else
{
    # Check for CONTRAST environment variables
    # If they don't exist, write out an error, but continue
    $url = GetEnvVar "CONTRAST__API__URL" "CONTRAST_TeamServerUrl"
    $user = GetEnvVar "CONTRAST__API__USER_NAME" "CONTRAST_TeamServerUserName"
    $apiKey = GetEnvVar "CONTRAST__API__API_KEY" "CONTRAST_TeamServerApiKey"
    $serviceKey = GetEnvVar "CONTRAST__API__SERVICE_KEY" "CONTRAST_TeamServerServiceKey"

    if ($null -eq $url)
    {
        Log "The environment variable CONTRAST__API__URL is not set. The agent will default to https://app.contrastsecurity.com"
    }
    if ($null -eq $user)
    {
        Log "The environment variable CONTRAST__API__USER_NAME must be set. Please make sure to add one."
    }
    if ($null -eq $apiKey)
    {
        Log "The environment variable CONTRAST__API__API_KEY must be set. Please make sure to add one."
    }
    if ($null -eq $serviceKey)
    {
        Log "The environment variable CONTRAST__API__SERVICE_KEY must be set. Please make sure to add one."
    }
}

Log "Installation completed successfully"
